@@ -1,16 +1,20 @@
-// 	$Id: main.m,v 1.3 1998/01/15 22:03:55 mgd Exp $	
+// 	$Id: main.m,v 1.6 1998/03/30 23:17:21 alex Exp $	
 
 #import "BoolNetObserverSwarm.h"
 #import "BoolNetBatchSwarm.h"
+#import <graph.h>
+#import <boolnet.h>
+#import <simtoolsgui.h>
 
 int
-main(int argc, char ** argv) {
+main (int argc, const char **argv)
+{
   BoolNetObserverSwarm * observerSwarm;
   BoolNetBatchSwarm * batchSwarm;
 
-  initSwarm(argc, argv);  
-  initGraphLibrary();
-  initBoolLibrary();
+  initSwarm (argc, argv);  
+  initGraphLibrary ();
+  initBoolLibrary ();
 
   // swarmGUIMode is set in initSwarm(). It's set to be 1 if your
   // DISPLAY environment variable is set (ie, you have an X server to
